@@ -34,6 +34,7 @@ if typing.TYPE_CHECKING:
     from ask_sdk_model.interfaces.geolocation.geolocation_state import GeolocationState as GeolocationState_5225020d
     from ask_sdk_model.interfaces.system.system_state import SystemState as SystemState_22fcb230
     from ask_sdk_model.interfaces.display.display_state import DisplayState as DisplayState_726e4959
+    from ask_sdk_model.interfaces.alexa.datastore.packagemanager.package_manager_state import PackageManagerState as PackageManagerState_9a27c921
 
 
 class Context(object):
@@ -57,6 +58,8 @@ class Context(object):
     :type viewports: (optional) list[ask_sdk_model.interfaces.viewport.typed_viewport_state.TypedViewportState]
     :param extensions: Provides the current state for Extensions interface
     :type extensions: (optional) ask_sdk_model.interfaces.alexa.extension.extensions_state.ExtensionsState
+    :param alexa_data_store_package_manager: Provides the current state for the Alexa.DataStore.PackageManager interface.
+    :type alexa_data_store_package_manager: (optional) ask_sdk_model.interfaces.alexa.datastore.packagemanager.package_manager_state.PackageManagerState
     :param app_link: Provides the current state for app link capability.
     :type app_link: (optional) ask_sdk_model.interfaces.applink.app_link_state.AppLinkState
     :param experimentation: Provides the current experimentation state
@@ -73,6 +76,7 @@ class Context(object):
         'viewport': 'ask_sdk_model.interfaces.viewport.viewport_state.ViewportState',
         'viewports': 'list[ask_sdk_model.interfaces.viewport.typed_viewport_state.TypedViewportState]',
         'extensions': 'ask_sdk_model.interfaces.alexa.extension.extensions_state.ExtensionsState',
+        'alexa_data_store_package_manager': 'ask_sdk_model.interfaces.alexa.datastore.packagemanager.package_manager_state.PackageManagerState',
         'app_link': 'ask_sdk_model.interfaces.applink.app_link_state.AppLinkState',
         'experimentation': 'ask_sdk_model.interfaces.alexa.experimentation.experimentation_state.ExperimentationState'
     }  # type: Dict
@@ -87,13 +91,14 @@ class Context(object):
         'viewport': 'Viewport',
         'viewports': 'Viewports',
         'extensions': 'Extensions',
+        'alexa_data_store_package_manager': 'Alexa.DataStore.PackageManager',
         'app_link': 'AppLink',
         'experimentation': 'Experimentation'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, system=None, alexa_presentation_apl=None, audio_player=None, automotive=None, display=None, geolocation=None, viewport=None, viewports=None, extensions=None, app_link=None, experimentation=None):
-        # type: (Optional[SystemState_22fcb230], Optional[RenderedDocumentState_4fad8b14], Optional[AudioPlayerState_ac652451], Optional[AutomotiveState_2b614eea], Optional[DisplayState_726e4959], Optional[GeolocationState_5225020d], Optional[ViewportState_a05eceb9], Optional[List[TypedViewportState_c366f13e]], Optional[ExtensionsState_f02207d3], Optional[AppLinkState_370eda23], Optional[ExperimentationState_37bb7c62]) -> None
+    def __init__(self, system=None, alexa_presentation_apl=None, audio_player=None, automotive=None, display=None, geolocation=None, viewport=None, viewports=None, extensions=None, alexa_data_store_package_manager=None, app_link=None, experimentation=None):
+        # type: (Optional[SystemState_22fcb230], Optional[RenderedDocumentState_4fad8b14], Optional[AudioPlayerState_ac652451], Optional[AutomotiveState_2b614eea], Optional[DisplayState_726e4959], Optional[GeolocationState_5225020d], Optional[ViewportState_a05eceb9], Optional[List[TypedViewportState_c366f13e]], Optional[ExtensionsState_f02207d3], Optional[PackageManagerState_9a27c921], Optional[AppLinkState_370eda23], Optional[ExperimentationState_37bb7c62]) -> None
         """
 
         :param system: Provides information about the current state of the Alexa service and the device interacting with your skill.
@@ -114,6 +119,8 @@ class Context(object):
         :type viewports: (optional) list[ask_sdk_model.interfaces.viewport.typed_viewport_state.TypedViewportState]
         :param extensions: Provides the current state for Extensions interface
         :type extensions: (optional) ask_sdk_model.interfaces.alexa.extension.extensions_state.ExtensionsState
+        :param alexa_data_store_package_manager: Provides the current state for the Alexa.DataStore.PackageManager interface.
+        :type alexa_data_store_package_manager: (optional) ask_sdk_model.interfaces.alexa.datastore.packagemanager.package_manager_state.PackageManagerState
         :param app_link: Provides the current state for app link capability.
         :type app_link: (optional) ask_sdk_model.interfaces.applink.app_link_state.AppLinkState
         :param experimentation: Provides the current experimentation state
@@ -130,6 +137,7 @@ class Context(object):
         self.viewport = viewport
         self.viewports = viewports
         self.extensions = extensions
+        self.alexa_data_store_package_manager = alexa_data_store_package_manager
         self.app_link = app_link
         self.experimentation = experimentation
 
