@@ -35,6 +35,10 @@ class ScrollCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param distance: The number of pages to scroll. Defaults to 1.
@@ -47,6 +51,8 @@ class ScrollCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'distance': 'int',
         'component_id': 'str'
@@ -56,20 +62,26 @@ class ScrollCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'distance': 'distance',
         'component_id': 'componentId'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, distance=None, component_id=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Union[int, str, None], Optional[str]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, distance=None, component_id=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Union[int, str, None], Optional[str]) -> None
         """Scroll a ScrollView or Sequence forward or backward by a number of pages. The Scroll command has the following properties in addition to the regular command properties.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param distance: The number of pages to scroll. Defaults to 1.
@@ -80,7 +92,7 @@ class ScrollCommand(Command):
         self.__discriminator_value = "Scroll"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(ScrollCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(ScrollCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.distance = distance
         self.component_id = component_id
 
